@@ -1,5 +1,5 @@
 from threading import Thread
-from easy_events import *
+from easy_events import Events, AsyncEvents, Parameters
 import asyncio, time, gc
 
 
@@ -7,6 +7,7 @@ class Debug():
     def __init__(self):
         self.sync = Events(first_parameter_object=False)
         self.asyn = AsyncEvents(first_parameter_object=False)
+        self.run = True
         Thread(target=self._inputs).start()
 
     def get_object(self, object: str):
@@ -38,7 +39,7 @@ class Debug():
         return [base, mid, method]
 
     def _inputs(self):
-        while True:
+        while self.run:
             command = input("> ")
 
             if not command:
@@ -94,7 +95,10 @@ class Debug():
     def _execute(self, command):
         self.sync.trigger(command, None)
 
-    def event(self, callback: callable):
+    def stop(self):
+        self.run = False
+
+    def event(self, callback: callable, aliases: list = []):
         event_type = None
 
         if "." in str(callback):
